#
# spec file for package libhinawa
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libhinawa
Version:        2.4.0
Release:        1.8
Summary:        I/O library for IEEE 1394 asynchronous transactions
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
URL:            https://github.com/alsa-project/libhinawa
Source0:        https://github.com/alsa-project/libhinawa/releases/download/%{version}/%{name}-%{version}.tar.xz
BuildRequires:  gobject-introspection-devel
BuildRequires:  gtk-doc
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-2.0)

%description
I/O library for IEEE 1394 asynchronous transactions to/from units on the bus,
with GObject Introspection.

%package -n libhinawa2
Summary:        I/O library for IEEE 1394 asynchronous transactions
Group:          System/Libraries

%description -n libhinawa2
I/O library for IEEE 1394 asynchronous transactions to/from units on the bus,
with GObject Introspection.

%package devel
Summary:        Header files for libhinawa, a lib for IEEE 1394 async transactions
Group:          Development/Libraries/C and C++
Requires:       libhinawa2 = %{version}

%description devel
This package contains all necessary include files and libraries needed
to develop applications that require libhinawa.

%package -n typelib-1_0-Hinawa-2_0
Summary:        Introspection bindings for libhinawa
Group:          System/Libraries
Requires:       libhinawa2 = %{version}

%description -n typelib-1_0-Hinawa-2_0
This package provides the GObject Introspection bindings for libhinawa,
an I/O library for IEEE 1394 asynchronous transactions.

%prep
%setup -q

%build
%meson -Dgtk_doc=true
%meson_build

%install
%meson_install

mkdir -p %{buildroot}%{_docdir}/%{name}
cp README* %{buildroot}%{_docdir}/%{name}
mv %{buildroot}%{_datadir}/gtk-doc/html/hinawa \
   %{buildroot}%{_docdir}/%{name}/html

%post -n libhinawa2 -p /sbin/ldconfig
%postun -n libhinawa2 -p /sbin/ldconfig

%files -n libhinawa2
%{_libdir}/libhinawa.so.2
%{_libdir}/libhinawa.so.2.*

%files devel
%doc %{_docdir}/%{name}
%{_includedir}/libhinawa
%{_datadir}/gir-1.0/*.gir
%{_libdir}/libhinawa.so
%{_libdir}/pkgconfig/*.pc

%files -n typelib-1_0-Hinawa-2_0
%{_libdir}/girepository-1.0/*

%changelog
* Mon May  9 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 2.4.0
  * Some symbols are newly available as public API for new features
* Thu Apr 15 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 2.2.0:
  * Some symbols are newly available as public API for new features.
  * HinawaFwResp::requested2 is added to deprecate HinawaFwResp::requested
  * Current implementation of HinawaFwResp::requested signal doesn't deliver
    all information in data of struct fw_cdev_event_request2 type.
    This is inconvenient for some applications bound to device which
    sends transactions to different addresses within a certain space.
    At release v2.1.0, nothing was added for error reporting of
    HinawaFwResp since it was not necessary. However, it's
    convenient to retrieve error reporting at failure of
    allocation in 1394 OHCI controller.
  * HinawaFwRespError enumeration is added and
    hinawa_fw_resp_error_quark() represents the domain of GError
    with the code in enumeration.
* Wed Aug 26 2020 tiwai@suse.de
- Updated to version 2.0.0:
  Major version updates includes refactoring and code cleanup to
  dismiss obsoleted stuffs added by period of version 1, toward
  better language bindings such as Python 3 and Rust.
- Updated to version 2.1.0:
  Minor version update so that some symbols are newly available as
  public API.
- Update subpackage SO version: libhinawa2
- Update URL
* Tue Jan  8 2019 Jan Engelhardt <jengelh@inai.de>
- Rectify SRPM group. Update descriptions.
* Wed Jan  2 2019 tiwai@suse.de
- Updated to version 1.1.0:
  support of new GObject object HinawaSndTscm
* Mon Dec 10 2018 tiwai@suse.de
- Initial verison: 1.0.1
